package com.xinda.itsm.service.impl;

import java.util.List;
import com.xinda.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.xinda.itsm.mapper.DutyMapper;
import com.xinda.itsm.domain.Duty;
import com.xinda.itsm.service.IDutyService;

/**
 * 值班管理Service业务层处理
 * 
 * @author kerwincui
 * @date 2025-04-23
 */
@Service
public class DutyServiceImpl implements IDutyService 
{
    @Autowired
    private DutyMapper dutyMapper;

    /**
     * 查询值班管理
     * 
     * @param dutyId 值班管理主键
     * @return 值班管理
     */
    @Override
    public Duty selectDutyByDutyId(Long dutyId)
    {
        return dutyMapper.selectDutyByDutyId(dutyId);
    }

    /**
     * 查询值班管理列表
     * 
     * @param duty 值班管理
     * @return 值班管理
     */
    @Override
    public List<Duty> selectDutyList(Duty duty)
    {
        return dutyMapper.selectDutyList(duty);
    }

    /**
     * 新增值班管理
     * 
     * @param duty 值班管理
     * @return 结果
     */
    @Override
    public int insertDuty(Duty duty)
    {
        duty.setCreateTime(DateUtils.getNowDate());
        return dutyMapper.insertDuty(duty);
    }

    /**
     * 修改值班管理
     * 
     * @param duty 值班管理
     * @return 结果
     */
    @Override
    public int updateDuty(Duty duty)
    {
        duty.setUpdateTime(DateUtils.getNowDate());
        return dutyMapper.updateDuty(duty);
    }

    /**
     * 批量删除值班管理
     * 
     * @param dutyIds 需要删除的值班管理主键
     * @return 结果
     */
    @Override
    public int deleteDutyByDutyIds(Long[] dutyIds)
    {
        return dutyMapper.deleteDutyByDutyIds(dutyIds);
    }

    /**
     * 删除值班管理信息
     * 
     * @param dutyId 值班管理主键
     * @return 结果
     */
    @Override
    public int deleteDutyByDutyId(Long dutyId)
    {
        return dutyMapper.deleteDutyByDutyId(dutyId);
    }
}
